@@ -1,11 +1,11 @@
 #!/bin/bash
-# memcached	(http://www.danga.com/memcached/)
-#	BuildScript for Plamo Linux 4.5
-#			by Jun Kuwamura <juk@linet.gr.jp> on 2008-07-08
+# memcached	(http://memcached.org/)
+#	BuildScript for Plamo Linux 4.7x
+#			by Jun Kuwamura <juk@linet.gr.jp> on 2011-05-21
 # require:
 #	libevent-1.4.x
 #
-SRC_URI=http://www.danga.com/memcached/dist/memcached-1.2.6.tar.gz
+SRC_URI=http://memcached.googlecode.com/files/memcached-1.4.5.tar.gz
 SRC_FILE=${SRC_URI##*/}
 SRC_NAME=${SRC_FILE%%.tar.gz}
 PAC_NAME=${SRC_NAME%%-stable}
@@ -17,7 +17,7 @@ SYS_NAME="${CPU}-${REL}"
 
 PLAMO=/expo/Build
 SRC_DIR=$PLAMO/Archive/network
-PAC_DIR=$PLAMO/Packages/4.5/Network
+PAC_DIR=$PLAMO/Packages/4.7/Memcache
 BUILD_DIR=$PLAMO/memcached
 CUSTOM_DIR=$BUILD_DIR/Custom
 
@@ -55,7 +55,7 @@ make install DESTDIR=$WORK
 DOC_DIR=$WORK/usr/share/doc/$PAC_NAME
 mkdir -p $DOC_DIR
 cp -p $BUILD_DIR/`basename $0`  \
-    AUTHORS COPYING ChangeLog INSTALL NEWS README TODO  \
+    AUTHORS COPYING ChangeLog NEWS README \
     doc/*.txt  \
   $DOC_DIR/
 chown -R root.root $DOC_DIR/
@@ -65,10 +65,10 @@ chmod -R a+rX,go-w $DOC_DIR/
 cd $WORK
 echo "y
 1
-" | makepkg ${PAC_NAME}.tgz
+" | makepkg ${PAC_NAME}-${SYS_NAME}.tgz
 
 echo -n "$PAC_DIR/${PAC_NAME}-${SYS_NAME}.tgz"
-if `mv -v ${PAC_NAME}.tgz  $PAC_DIR/${PAC_NAME}-${SYS_NAME}.tgz 1>/dev/null 2>&1`; then
+if `mv -v ${PAC_NAME}-${SYS_NAME}.tgz  $PAC_DIR/${PAC_NAME}-${SYS_NAME}.tgz 1>/dev/null 2>&1`; then
   echo " ... done"
 else
   echo " ... false"
